==> emodpy_covid-0.0.50-py3-none-any.whl: emodpy_covid/interventions/quarantine.py <==
from emod_api import schema_to_class as s2c
import json
import pdb

def Quarantine( coverage=1.0, delay=0, quality=1.0, trigger="NoTrigger", timestep=1, nods=[] ):
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "CommunityHealthWorkerEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    event.Event_Coordinator_Config = coordinator
    intervention = s2c.get_class_with_defaults( "SimpleVaccine", schema_path )
    coordinator.Intervention_Config = intervention
    event.Start_Day = float(timestep)

    coordinator.Duration = 1000
    coordinator.Max_Distributed_Per_Day = 1e9
    coordinator.Waiting_Period = 1000.0
    coordinator.Days_Between_Shipments = 1000
    coordinator.Amount_In_Shipment = 0
    coordinator.Max_Stock = 1e9
    #coordinator.Initial_Amount_Distribution = 'CONSTANT_DISTRIBUTION'
    coordinator.Initial_Amount_Constant = 1e9
    coordinator.Trigger_Condition_List = [ trigger ] # a list of 1....

    intervention.Cost_To_Consumer = 0
    intervention.Intervention_Name = "covid_qurantine"
    intervention.Vaccine_Take = coverage
    intervention.Vaccine_Type = "TransmissionBlocking"
                     
    waning = s2c.get_class_with_defaults( "WaningEffectMapPiecewise", schema_path )
    waning.Initial_Effect = 1.0
    waning.Durability_Map = {
            'Times': [0.0, 1.0 + delay],
            'Values': [0.0, quality ]
        }
    intervention.Waning_Config = waning

    if len(nods) > 0:
        nodelist = s2c.get_class_with_defaults( "NodeSetNodeList", schema_path )
        nodelist.Node_List = nods
        event.Nodeset_Config = nodelist
        nodelist.finalize()

    coordinator.finalize()
    intervention.finalize()
    waning.finalize()
    event.finalize()
    event["Event_Name"] = "Quarantine..."

    return event

==> emodpy_covid-0.0.53-py3-none-any.whl: emodpy_covid/interventions/quarantine.py <==
from emod_api import schema_to_class as s2c
import json

def Quarantine( coverage=1.0, delay=0, quality=1.0, trigger="NoTrigger", timestep=1, nods=[] ):
    event = s2c.get_class_with_defaults( "CampaignEvent", schema_path )
    coordinator = s2c.get_class_with_defaults( "CommunityHealthWorkerEventCoordinator", schema_path )
    if coordinator is None:
        print( "s2c.get_class_with_defaults returned None. Maybe no schema.json was provided." )
        return "" 
    event.Event_Coordinator_Config = coordinator
    intervention = s2c.get_class_with_defaults( "Vaccine", schema_path )
    coordinator.Intervention_Config = intervention
    event.Start_Day = float(timestep)

    coordinator.Duration = 1000
    coordinator.Max_Distributed_Per_Day = 1e9
    coordinator.Waiting_Period = 1000.0
    coordinator.Days_Between_Shipments = 1000
    coordinator.Amount_In_Shipment = 0
    coordinator.Max_Stock = 1e9
    #coordinator.Initial_Amount_Distribution = 'CONSTANT_DISTRIBUTION'
    coordinator.Initial_Amount_Constant = 1e9
    coordinator.Trigger_Condition_List = [ trigger ] # a list of 1....

    intervention.Cost_To_Consumer = 0
    intervention.Intervention_Name = "covid_qurantine"
    intervention.Vaccine_Take = coverage
    #intervention.Vaccine_Type = "TransmissionBlocking"
                     
    waning = s2c.get_class_with_defaults( "WaningEffectMapPiecewise", schema_path )
    waning.Initial_Effect = 1.0
    waning.Durability_Map = {
            'Times': [0.0, 1.0 + delay],
            'Values': [0.0, quality ]
        }
    intervention.Transmit_Config = waning

    if len(nods) > 0:
        nodelist = s2c.get_class_with_defaults( "NodeSetNodeList", schema_path )
        nodelist.Node_List = nods
        event.Nodeset_Config = nodelist
        nodelist.finalize()

    coordinator.finalize()
    intervention.finalize()
    waning.finalize()
    event.finalize()
    event["Event_Name"] = "Quarantine..."

    return event
